# History

All notable changes to this project will be documented in this file. This project adheres to [Semantic Versioning](http://semver.org/).

## 0.1.0 (2025-10-30)

- First release

## 0.1.1 (2025-10-30)

- Added `start` as an alias for `monitor`.

## 0.1.2 (2025-10-30)

- Fix lookup error
